@@ -18,9 +18,12 @@ from .constants import (
     THRESHOLD_KEY,
     ThresholdComparison,
 )
-from .data_transfer_objects.scenario_test_evaluations import GetEvalHistory
+from .data_transfer_objects.scenario_test_evaluations import EvaluationResult
 from .data_transfer_objects.scenario_test_metric import AddScenarioTestFunction
-from .eval_functions.available_eval_functions import EvalFunction
+from .eval_functions.available_eval_functions import (
+    EvalFunction,
+    ExternalEvalFunction,
+)
 from .scenario_test_evaluation import ScenarioTestEvaluation
 from .scenario_test_metric import ScenarioTestMetric
 
@@ -46,13 +49,24 @@ class ScenarioTest:
     slice_id: str = field(init=False)
     baseline_model_id: Optional[str] = None
 
-    def __post_init__(self):
+    @classmethod
+    def from_id(cls, unit_test_id: str, connection: Connection):
         # TODO(gunnar): Remove this pattern. It's too slow. We should get all the info required in one call
-        response = self.connection.get(
-            f"validate/scenario_test/{self.id}/info",
+        response = connection.get(
+            f"validate/scenario_test/{unit_test_id}/info",
         )
-        self.name = response[NAME_KEY]
-        self.slice_id = response[SLICE_ID_KEY]
+        instance = cls(unit_test_id, connection)
+        instance.name = response[NAME_KEY]
+        instance.slice_id = response[SLICE_ID_KEY]
+        return instance
+
+    @classmethod
+    def from_response(cls, response, connection: Connection):
+        instance = cls(response["id"], connection)
+        instance.name = response[NAME_KEY]
+        instance.slice_id = response[SLICE_ID_KEY]
+        instance.baseline_model_id = response.get("baseline_model_id", None)
+        return instance
 
     def add_eval_function(
         self, eval_function: EvalFunction
@@ -83,9 +97,13 @@ class ScenarioTest:
         Args:
             eval_function: :class:`EvalFunction`
 
+        Raises:
+            NucleusAPIError: By adding this function, the scenario test mixes external with non-external functions which is not permitted.
+
         Returns:
             The created ScenarioTestMetric object.
         """
+
         response = self.connection.post(
             AddScenarioTestFunction(
                 scenario_test_name=self.name,
@@ -93,7 +111,7 @@ class ScenarioTest:
             ).dict(),
             "validate/scenario_test_eval_function",
         )
-        print(response)
+
         return ScenarioTestMetric(
             scenario_test_id=response[SCENARIO_TEST_ID_KEY],
             eval_function_id=response[EVAL_FUNCTION_ID_KEY],
@@ -138,13 +156,13 @@ class ScenarioTest:
             A list of :class:`ScenarioTestEvaluation` objects.
         """
         response = self.connection.get(
-            f"validate/scenario_test/{self.id}/eval_history",
+            f"validate/scenario_test/{self.id}/eval_history/details",
         )
-        eval_history = GetEvalHistory.parse_obj(response)
-        return [
-            ScenarioTestEvaluation(evaluation.id, self.connection)
-            for evaluation in eval_history.evaluations
+        evaluations = [
+            ScenarioTestEvaluation.from_request(eval_payload, self.connection)
+            for eval_payload in response
         ]
+        return evaluations
 
     def get_items(self) -> List[DatasetItem]:
         response = self.connection.get(
@@ -174,3 +192,43 @@ class ScenarioTest:
         )
         self.baseline_model_id = response.get("baseline_model_id")
         return self.baseline_model_id
+
+    def upload_external_evaluation_results(
+        self,
+        eval_fn: ExternalEvalFunction,
+        results: List[EvaluationResult],
+        model_id: str,
+    ):
+        assert (
+            eval_fn.eval_func_entry.is_external_function
+        ), "Submitting evaluation results is only available for external functions."
+
+        assert (
+            len(results) > 0
+        ), "Submitting evaluation requires at least one result."
+
+        metric_per_ref_id = {}
+        weight_per_ref_id = {}
+        aggregate_weighted_sum = 0.0
+        aggregate_weight = 0.0
+        # aggregation based on https://en.wikipedia.org/wiki/Weighted_arithmetic_mean
+        for r in results:
+            metric_per_ref_id[r.item_ref_id] = r.score
+            weight_per_ref_id[r.item_ref_id] = r.weight
+            aggregate_weighted_sum += r.score * r.weight
+            aggregate_weight += r.weight
+
+        payload = {
+            "unit_test_id": self.id,
+            "eval_function_id": eval_fn.id,
+            "result_per_ref_id": metric_per_ref_id,
+            "weight_per_ref_id": weight_per_ref_id,
+            "overall_metric": aggregate_weighted_sum / aggregate_weight,
+            "model_id": model_id,
+            "slice_id": self.slice_id,
+        }
+        response = self.connection.post(
+            payload,
+            "validate/scenario_test/upload_results",
+        )
+        return response
