@@ -4,5 +4,5 @@ from typing import Optional
 def try_convert_float(float_str: str) -> Optional[float]:
     try:
         return float(float_str)
-    except ValueError:
+    except (ValueError, TypeError):
         return None
